// IMU8420 Case Designs
// Designed by SOC Robotics, Inc.
// (c) Copyright 2016 SOC Robotics, Inc.  All rights reserved.
// Free to use but not for resell.
// Version: 1.00  Released March 31, 2016
// Designed using openSCAD version 2015.03-2

// The case design houses the IMU8420 10 DOF datalogger.
// The IMU8420 is available with or with an optional GPS mounted receiver
// and two different style of tabs (or no tabs).
// Load include scad file
use <rounded_box.scad>

// Select print mode or assembly display mode
forprint = 1;   // Set to one for printing
//forprint = 0;   // Set to zero for assembly view

// There are two external tab variations:  screw hold mount or wrist strap
// Screw mount selection
addtabs = 2;    // Add one or two screw mount tabs
//addtabs = 0;  // Disable screw mount tabs

// Wrist strap selection
//addstraps = 1;  // Add slots for a verco or fabric strap
addstraps = 0;    // Disable wrist strap tabs
strapwidth = 15;

// Select the component to view
//case_bottom();
//case_top();
//case_top_gps();
//assembly();
assembly_gps();


// Bottom case
module case_bottom(){
   
    $fn=40;
    
    difference() {
        union() {
            difference(){
                rounded_box(64,38,16.5,0.9,1.5);
                // I2C connector
                translate([64-1.5-0.01,6.3,9+1.5+1.61]) cube([5,7.7,3.8]);
                // Power switch
                translate([64-1.5-0.01,6.3+9.5,9+2+1.61]) cube([4.0,4.2,2.9]);
                translate([64-1.5-0.01,6.3+7.5,9+1.8+1.61]) cube([0.8,9,4.3]);
                // USB slot
                translate([64-1.5-0.01,6.3+17.0,11.8]) cube([5,9,8.1]);
                // uSD slot
                translate([45,-3,9+1.3+1.61]) cube([14,5,2.4]);
                }
            // Alignment pins
            translate([3.1,3.1,1.5]) cylinder(h=10,d=1.63);
            translate([3.1,3.1,1.5]) cylinder(h=9,d=3);    
            translate([64-4.1,38-3.1,1.5]) cylinder(h=10,d=1.63);
            translate([64-4.1,38-3.1,1.5]) cylinder(h=9,d=3);    
            // Support pins
            translate([3.1,38-3.1,1.5]) cylinder(h=9,d=3);
            translate([64-3.1,3.1,1.5]) cylinder(h=9,d=3);
            // Battery holder - modify to suit battery
            // This fits 350mah Lithium measuring 29x40
            difference() {
                translate([7,38/2-21/2,1.45]) cube([41.2,23,6]);
                translate([8,38/2-19/2,1.45]) cube([39.2,21,7]);
                translate([41,38/2-19/2-2,1.45]) cube([8,8,8]);
                }
            if(addtabs>0) {
                difference() {
                    hull() {
                        translate([-11,0,0]) cube([12,38,3]); 
                        translate([-11,3,0]) cylinder(h=3,r=3);
                        translate([-11,35,0]) cylinder(h=3,r=3);
                        }  
                    translate([-8,7,-0.1]) cylinder(h=4,r=3);
                    translate([-8,31,-0.1]) cylinder(h=4,r=3);
                    }    
                }
            if(addtabs==2) {
                translate([64.0,0,3]) rotate([0,180,0])
                difference() {
                    hull() {
                        translate([-11,0,0]) cube([12,38,3]); 
                        translate([-11,3,0]) cylinder(h=3,r=3);
                        translate([-11,35,0]) cylinder(h=3,r=3);
                        }  
                    translate([-8,7,-0.1]) cylinder(h=4,r=3);
                    translate([-8,31,-0.1]) cylinder(h=4,r=3);
                    }    
                }
            if(addstraps>0) {
                translate([48.0,0,0]) rotate([0,0,90])
                difference() {
                   hull() {
                       translate([-11,0,0]) cube([12,31,3]); 
                       translate([-11,3,0]) cylinder(h=3,r=3);
                       translate([-11,28,0]) cylinder(h=3,r=3);
                       }  
                   translate([-10,6,-0.1]) cube([6,20,4]);
                   }    
                translate([18.0,39,0]) rotate([0,0,-90])
                difference() {
                   hull() {
                       translate([-11,0,0]) cube([12,31,3]); 
                       translate([-11,3,0]) cylinder(h=3,r=3);
                       translate([-11,28,0]) cylinder(h=3,r=3);
                       }  
                   translate([-10,6,-0.1]) cube([6,20,4]);
                   }    
               }
            }
        // Screw holes
        translate([3.1,3.1,6]) cylinder(h=9,d=1.5);
        translate([64-4.1,38-3.1,6]) cylinder(h=9,d=1.5);    
        }
}

module case_top(){
    $fn=50;
    difference() {
        difference() {
            union() {
                rounded_box(64,38,4,0.9,1.5);
                
                // Holding pins
                translate([3.1,38-3.1,1.5]) cylinder(h=6.3,d=3.1);
                translate([64-4.3,3.1,1.5]) cylinder(h=6.3,d=3.1);
                translate([3.1,3.1,1.5]) cylinder(h=6.3,d=3.1);
                translate([64-3.1,38-3.1,1.5]) cylinder(h=5,d=3.1);
                }
            // Screw holes
            translate([64-4.3,3.1,-0.1]) cylinder(h=9,d=2.3);
            translate([64-4.3,3.1,-0.1]) cylinder(h=2.5,d1=4.5,d2=0);    
            translate([3.1,38-3.1,-0.1]) cylinder(h=9,d=2.3); 
            translate([3.1,38-3.1,-0.1]) cylinder(h=2.5,d1=4.5,d2=0);     
            }
        // Text on lid top
        translate([6,30,0.35]) rotate([180,0,-90]) linear_extrude(1)text(text = "IMU8420", size = 4);
         translate([12,6,0.35]) rotate([180,0,0]) linear_extrude(1)text(text = "Data Logger", size = 4);
   }
}

module case_top_gps(){
    $fn=50;
    difference() {
        difference() {
            union() {
                rounded_box(64,38,4,0.9,1.5);
                
                // Holding pins
                translate([3.1,38-3.1,1.5]) cylinder(h=6.3,d=3.1);
                translate([64-4.3,3.1,1.5]) cylinder(h=6.3,d=3.1);
                translate([3.1,3.1,1.5]) cylinder(h=6.3,d=3.1);
                translate([64-3.1,38-3.1,1.5]) cylinder(h=5,d=3.1);
                }
            // Screw holes
            translate([64-4.3,3.1,-0.1]) cylinder(h=9,d=2.3);
            translate([64-4.3,3.1,-0.1]) cylinder(h=2.5,d1=4.5,d2=0);    
            translate([3.1,38-3.1,-0.1]) cylinder(h=9,d=2.3); 
            translate([3.1,38-3.1,-0.1]) cylinder(h=2.5,d1=4.5,d2=0);    
            }
            translate([6,32,0.35]) rotate([180,0,-90]) linear_extrude(1)text(text = "IMU8420", size = 4);
            translate([12,6,0.35]) rotate([180,0,0]) linear_extrude(1)text(text = "Data Logger", size = 4);
            // Hole for gps in top cover
        translate([19,9.2,-0.1]) cube([15.5,15.7,3]);    
    }
}

module assembly() {
    color("Grey");
    case_bottom();
    if(forprint==1)  translate([0,55,0]) case_top();  // For printing
    else translate([0,38,21]) rotate([0,180,180]) case_top();  // For checking alignment
}


module assembly_gps() {
    color("Grey");
    case_bottom();
    if(forprint==1) translate([0,55,0]) case_top_gps();
    else translate([0,38,21]) rotate([0,180,180]) case_top_gps();  // For checking alignment
}



//translate([0,0,21]) cube([17.5,13.2,2]);


